[05/27] sim: moxie: invert sim_cpu storage

Message ID 20221101151158.24916-6-vapier@gentoo.org
State Committed
Commit 778ef9bcbb268228bf6ad0171cf9f539979208c8
Headers
Series sim: sim_cpu: invert sim_cpu storage |

Commit Message

Mike Frysinger Nov. 1, 2022, 3:11 p.m. UTC
  ---
 sim/moxie/interp.c   |  9 +++++----
 sim/moxie/sim-main.h | 18 ++++++++----------
 2 files changed, 13 insertions(+), 14 deletions(-)
  

Patch

diff --git a/sim/moxie/sim-main.h b/sim/moxie/sim-main.h
index 9e4b1d4f8bcd..7db12e01498b 100644
--- a/sim/moxie/sim-main.h
+++ b/sim/moxie/sim-main.h
@@ -20,23 +20,21 @@  along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 #ifndef SIM_MAIN_H
 #define SIM_MAIN_H
 
+#define SIM_HAVE_COMMON_SIM_CPU
+
 #include "sim-basics.h"
 #include "sim-base.h"
 #include "bfd.h"
 
 #define PCIDX 17
 
-struct _sim_cpu {
-
-  /* The following are internal simulator state variables: */
-
-/* To keep this default simulator simple, and fast, we use a direct
-   vector of registers. The internal simulator engine then uses
-   manifests to access the correct slot. */
-
+struct moxie_sim_cpu {
+  /* To keep this default simulator simple, and fast, we use a direct
+     vector of registers. The internal simulator engine then uses
+     manifests to access the correct slot. */
   unsigned_word registers[19];
-
-  sim_cpu_base base;
 };
 
+#define MOXIE_SIM_CPU(cpu) ((struct moxie_sim_cpu *) CPU_ARCH_DATA (cpu))
+
 #endif
diff --git a/sim/moxie/interp.c b/sim/moxie/interp.c
index 325bd14e313f..6b2cf06cb8b5 100644
--- a/sim/moxie/interp.c
+++ b/sim/moxie/interp.c
@@ -127,7 +127,7 @@  struct moxie_regset
 #define CC_GTU 1<<3
 #define CC_LTU 1<<4
 
 /* TODO: This should be moved to sim-main.h:_sim_cpu.  */
 union
 {
   struct moxie_regset asregs;
@@ -1173,13 +1173,13 @@  moxie_reg_fetch (SIM_CPU *scpu, int rn, unsigned char *memory, int length)
 static sim_cia
 moxie_pc_get (sim_cpu *cpu)
 {
-  return cpu->registers[PCIDX];
+  return MOXIE_SIM_CPU (cpu)->registers[PCIDX];
 }
 
 static void
 moxie_pc_set (sim_cpu *cpu, sim_cia pc)
 {
-  cpu->registers[PCIDX] = pc;
+  MOXIE_SIM_CPU (cpu)->registers[PCIDX] = pc;
 }
 
 static void
@@ -1203,7 +1203,8 @@  sim_open (SIM_OPEN_KIND kind, host_callback *cb,
   current_target_byte_order = BFD_ENDIAN_BIG;
 
   /* The cpu data is kept in a separately allocated chunk of memory.  */
-  if (sim_cpu_alloc_all (sd, 1) != SIM_RC_OK)
+  if (sim_cpu_alloc_all_extra (sd, 1, sizeof (struct moxie_sim_cpu))
+      != SIM_RC_OK)
     {
       free_state (sd);
       return 0;
@@ -127,7 +127,7 @@  struct moxie_regset
 #define CC_LTU 1<<4
 
-/* TODO: This should be moved to sim-main.h:_sim_cpu.  */
+/* TODO: This should be moved to sim-main.h:moxie_sim_cpu.  */
 union
 {